SystemOrganization addCategory: #BackgammonModel!

TestCase subclass: #BackgammonModelTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

TestCase subclass: #CheckerTestCase
	instanceVariableNames: 'checkerObserver checkerOnBar checkerOnPoint mockCheckerView barLocation pointLocation movableChecker'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!CheckerTestCase methodsFor: 'testing' stamp: 'AhmedSoliman 7/13/2015 15:11'!
setUp
	barLocation := BarLocation new .
	pointLocation := PointLocation new number:1.
	checkerOnPoint := Checker new location: pointLocation color:  (Color red).
	checkerOnBar := Checker new location: barLocation color:  (Color red).
	
	movableChecker := Checker new location: barLocation color:  (Color blue).
	movableChecker initialize .
	mockCheckerView := MockView new.
	movableChecker addObserver: mockCheckerView .! !

!CheckerTestCase methodsFor: 'testing' stamp: 'AhmedSoliman 7/13/2015 14:59'!
testInitialize
	"Create a Checker"
	
	Transcript show:(checkerOnPoint printString).
	self assert: (checkerOnPoint isNotNil ).
	self assert:(checkerOnPoint color = Color red).

! !

!CheckerTestCase methodsFor: 'as yet unclassified' stamp: 'jChizmar 7/14/2015 19:36'!
testObserver
	"test moving the checker from bar to point"
	movableChecker moveChecker: pointLocation ! !

!CheckerTestCase methodsFor: 'testing' stamp: 'jChizmar 7/15/2015 21:30'!
testPrinting
	"Tests for printing out Checker"
	
	Transcript show:(checkerOnBar printString).
	self assert:(checkerOnBar printString = ('Checker Class -', (String cr) , 'Color:Color red', (String cr) , 'Location:BarLocation Class') ).
	
	self assert:(((checkerOnPoint checkerLocation) printString) = ('PointLocation Class -', (String cr), 'PointNumber:', '1')).

	! !

TestCase subclass: #MainBoardTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!MainBoardTest methodsFor: 'as yet unclassified' stamp: 'jChizmar 7/15/2015 21:20'!
testMainBoardInit
	"comment stating purpose of message"

	|myMainBoard|
	myMainBoard := MainBoard initialize.! !

TestCase subclass: #MoveCheckerCommandTestCase
	instanceVariableNames: 'barLocation pointLocation checkerOnPoint checkerOnBar'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!MoveCheckerCommandTestCase methodsFor: 'initialize' stamp: 'jChizmar 7/14/2015 19:27'!
setUp
	"Setup the Objects for Testing"
	barLocation := BarLocation new .
	pointLocation := PointLocation new number:1.
	checkerOnPoint := Checker new location: pointLocation color:  (Color red).
	checkerOnBar := Checker new location: barLocation color:  (Color red).! !

!MoveCheckerCommandTestCase methodsFor: 'initialize' stamp: 'jChizmar 7/15/2015 21:30'!
testInitialize
	"Tests the Initialization and setup of the MoveCheckerCommand"
	
	|moveCheckerCommand|
	moveCheckerCommand := (MoveCheckerCommand new) checker:checkerOnPoint  location: barLocation.
	moveCheckerCommand execute.
	self assert:((checkerOnPoint checkerLocation) = barLocation).

! !

!MoveCheckerCommandTestCase methodsFor: 'initialize' stamp: 'jChizmar 7/14/2015 19:29'!
testMoveChecker
	"This tests the move of a checker from locaiton to location"
! !

TestCase subclass: #PlayerTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!PlayerTestCase methodsFor: 'as yet unclassified' stamp: 'jChizmar 7/15/2015 20:46'!
testInitialize
	"comment stating purpose of message"

	|myPlayer|
	
	myPlayer := Player nameOfPlayer:'Jen' checkerColor:Color red.
	self assert:(myPlayer nameOfPlayer = 'Jen').! !

Object subclass: #Location
	instanceVariableNames: 'locationType'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!Location commentStamp: 'jChizmar 7/11/2015 20:56' prior: 0!
I am the model representation of one of the valid locations on the Backgammon board.  I am the super class of PointLocation, BarLocation, and OffLocation.   

My subclasses are referenced by the Checker to indicate what location on the board the checker is in.  


Public API and Key Messages

- 
  
Internal Representation and Key Implementation Points.

 

!

Location subclass: #BarLocation
	instanceVariableNames: 'pointNumber instance'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

BarLocation class
	instanceVariableNames: 'instance'!

!BarLocation commentStamp: 'jChizmar 7/11/2015 21:08' prior: 0!
I am the model representation of the Bar on the Backgammon board. My superclass isLocation. I am a singleton.

I am referenced by the Checker to indicate that the Checker is located on the Bar.  


Public API and Key Messages

- printOn
  
Internal Representation and Key Implementation Points.

 

!

BarLocation class
	instanceVariableNames: 'instance'!

!BarLocation class methodsFor: 'initialize' stamp: 'jChizmar 7/11/2015 21:30'!
new
    instance isNil ifTrue: [instance := super new].
    ^ instance! !

!BarLocation methodsFor: 'printing' stamp: 'jChizmar 7/11/2015 20:59'!
printOn: aStream
	aStream nextPutAll:'BarLocation Class'.! !

!Location methodsFor: 'printing' stamp: 'jChizmar 7/11/2015 21:00'!
printOn: aStream
	aStream nextPutAll:'Location Class'.! !

Location subclass: #OffLocation
	instanceVariableNames: 'player'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

OffLocation class
	instanceVariableNames: 'instance'!

!OffLocation commentStamp: 'jChizmar 7/11/2015 21:09' prior: 0!
I am the model representation of being off the board in Backgammon. My superclass isLocation. 

I am referenced by the Checker to indicate that the Checker is located on the  board.  


Public API and Key Messages

- player - gets the player that is associated with the off location
- player :- sets the player that is associated with the off location
- printOn
  
Internal Representation and Key Implementation Points.

 

!

OffLocation class
	instanceVariableNames: 'instance'!

!OffLocation class methodsFor: 'as yet unclassified' stamp: 'jChizmar 7/11/2015 21:32'!
player:playerIn
	^ self new
	player:playerIn.! !

!OffLocation methodsFor: 'accessing' stamp: 'jChizmar 7/11/2015 21:05'!
player
	^ pointNumber! !

!OffLocation methodsFor: 'accessing' stamp: 'jChizmar 7/11/2015 21:06'!
player: playerIn
	player := playerIn.! !

!OffLocation methodsFor: 'initialize' stamp: 'jChizmar 7/15/2015 21:48'!
playerInit: playerIn
	self player:playerIn.
	^self.! !

!OffLocation methodsFor: 'printing' stamp: 'jChizmar 7/13/2015 20:50'!
printOn:aStream 
	aStream nextPutAll:'Off Location Class -'; 
			  nextPutAll: (String cr); 
			  nextPutAll: 'Player:'; 
			  nextPutAll: ((self player) printString).! !

Location subclass: #PointLocation
	instanceVariableNames: 'pointNumber'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!PointLocation commentStamp: 'jChizmar 7/11/2015 21:09' prior: 0!
I am the model representation of one the Point locations on the Backgammon board. My superclass is location

I am referenced by the Checker to indicate that the Checker is located on a specific Point on the gameboard.


Public API and Key Messages

- pointNumber - gets the number of the point that is associated with the off location
- pointNumber :- sets the number of the point that is associated with the pointlocation
- printOn
  
Internal Representation and Key Implementation Points.

 

!

!PointLocation class methodsFor: 'initialize' stamp: 'jChizmar 7/11/2015 21:21'!
number: pointNumberIn 
	^ self new
		pointNumber:pointNumberIn.! !

!PointLocation methodsFor: 'initialize' stamp: 'jChizmar 7/11/2015 21:20'!
number: pointNumberIn
	self pointNumber:pointNumberIn.
	^self.! !

!PointLocation methodsFor: 'accessing' stamp: 'jChizmar 7/11/2015 21:06'!
pointNumber
	^pointNumber.! !

!PointLocation methodsFor: 'accessing' stamp: 'jChizmar 7/11/2015 21:01'!
pointNumber: pointNumberIn
	pointNumber := pointNumberIn.! !

!PointLocation methodsFor: 'printing' stamp: 'jChizmar 7/13/2015 20:55'!
printOn:aStream 
	aStream nextPutAll:'PointLocation Class -'; 
			  nextPutAll: (String cr);  
			  nextPutAll: 'PointNumber:'; 
			  nextPutAll: ((self pointNumber) printString).! !

Object subclass: #MainBoard
	instanceVariableNames: 'player1 player2 player1Checkers player2Checkers points bar player1Off player2Off'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!MainBoard commentStamp: 'AhmedSoliman 7/13/2015 14:52' prior: 0!
This is the mainboard of the backgammon game!

!MainBoard class methodsFor: 'initialize' stamp: 'jChizmar 7/15/2015 21:51'!
initialize
|mySelf  i  |

	mySelf :=self new.
	
		"initialize"
		
		
	"Create Players"
	 mySelf player1: (Player new name:'Jen' checkerColor:Color red).
	 mySelf player2: (Player new name:'Karen' checkerColor:Color black).
	
	"Create Board Locations"
	"Create Bar "
	mySelf bar: BarLocation new.
	
	"Create Points"
	i:=1.
	mySelf points: OrderedCollection new.
	[i<25] whileTrue: 
		[ mySelf points add: (PointLocation new number:i).
		i := i+1.].
	
	"Create Off"
	mySelf player1Off: ((OffLocation new) player: (mySelf player1)).
	mySelf player2Off: ((OffLocation new) player:(mySelf player2)).
	
	^mySelf.
! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 19:58'!
bar
	^ bar! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 19:58'!
bar: anObject
	bar := anObject! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 19:58'!
player1
	^ player1! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:55'!
player1: anObject
	player1 := anObject! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 19:58'!
player1Checkers
	^ player1Checkers! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:55'!
player1Checkers: anObject
	player1Checkers := anObject! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 19:58'!
player1Off
	^ player1Off! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:55'!
player1Off: anObject
	player1Off := anObject! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 19:58'!
player2
	^ player2! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:55'!
player2: anObject
	player2 := anObject! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 19:58'!
player2Checkers
	^ player2Checkers! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:55'!
player2Checkers: anObject
	player2Checkers := anObject! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 19:58'!
player2Off
	^ player2Off! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:55'!
player2Off: anObject
	player2Off := anObject! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 19:58'!
points
	^ points! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:55'!
points: anObject
	points := anObject! !

Object subclass: #MoveCheckerCommand
	instanceVariableNames: 'checkerToMove newLocation'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!MoveCheckerCommand commentStamp: 'jChizmar 7/14/2015 19:20' prior: 0!
I am a class that implements a Command called Move Checker

My main responsibility is to update the location of a checker to the location selected by the game.

I collaborate by calling methods on the Checker Class.  I take a location as input and I am called by the BGMController Class based on a user action. 

Public API and Key Messages

- execute - this method changes the location of the given checker.

  !

!MoveCheckerCommand class methodsFor: 'as yet unclassified' stamp: 'jChizmar 7/14/2015 19:33'!
checker: checkerIn location:locationIn
	^(self new) checker: checkerIn location: locationIn! !

!MoveCheckerCommand methodsFor: 'initialize' stamp: 'jChizmar 7/14/2015 19:33'!
checker: checkerIn location:locationIn
	self checkerToMove:checkerIn.
	self newLocation:locationIn.
	^self.! !

!MoveCheckerCommand methodsFor: 'accessing' stamp: 'jChizmar 7/14/2015 19:22'!
checkerToMove
	^ checkerToMove! !

!MoveCheckerCommand methodsFor: 'accessing' stamp: 'jChizmar 7/14/2015 19:22'!
checkerToMove: anObject
	checkerToMove := anObject! !

!MoveCheckerCommand methodsFor: 'initialize' stamp: 'jChizmar 7/14/2015 19:36'!
execute
	"Execute the MoveCheckerCommand"
	self checkerToMove moveChecker: (self newLocation).

	! !

!MoveCheckerCommand methodsFor: 'accessing' stamp: 'jChizmar 7/14/2015 19:22'!
newLocation
	^ newLocation! !

!MoveCheckerCommand methodsFor: 'accessing' stamp: 'jChizmar 7/14/2015 19:22'!
newLocation: anObject
	newLocation := anObject! !

Object subclass: #Observable
	instanceVariableNames: 'observers'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!Observable commentStamp: 'AhmedSoliman 7/11/2015 07:00' prior: 0!
Generic Observer pattern
To Do: 
Subclass Me for any model classes that need to notify the view for changes.!

Observable subclass: #Checker
	instanceVariableNames: 'locationOnBoard color'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!Checker commentStamp: 'jChizmar 7/14/2015 19:37' prior: 0!
I am the model representation of a checker on the backgammon board.

I hold the location and color of an individual checker. 

I am composed of a location (class in the Backgammon model) and a Smalltalk Color object.  

Public API and Key Messages

- color: - sets the color of the checker
- locationOnBoard: - sets the location of the checker.
- create instance by Checker new: <location> <color>

  
Internal Representation and Key Implementation Points.

    Instance Variables
	color:		<Color>
	moveChecker:		<Location>


!

!Checker class methodsFor: 'initialize' stamp: 'jChizmar 7/14/2015 19:36'!
location: locationIn color: colorIn 
	^ self new
		color: colorIn;
		moveChecker: locationIn.! !

!Checker methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 21:30'!
checkerLocation
	^ locationOnBoard! !

!Checker methodsFor: 'accessing' stamp: 'jChizmar 7/11/2015 19:29'!
color
	^ color! !

!Checker methodsFor: 'accessing' stamp: 'jChizmar 7/11/2015 19:29'!
color: colorIn
	color := colorIn! !

!Checker methodsFor: 'initialize' stamp: 'jChizmar 7/14/2015 19:36'!
location: locationIn color: colorInput
	self color:  colorInput.
	self moveChecker:  locationIn.
	^self.! !

!Checker methodsFor: 'accessing' stamp: 'jChizmar 7/14/2015 19:36'!
moveChecker: locationIn
	locationOnBoard := locationIn.
	self notifyObservers ! !

!Checker methodsFor: 'printing' stamp: 'jChizmar 7/15/2015 21:30'!
printOn: aStream
	aStream nextPutAll:'Checker Class -'; 
			  nextPutAll: (String cr);   
			  nextPutAll: 'Color:'; 
			  nextPutAll: ((self color) printString);
			  nextPutAll: (String cr); 
			  nextPutAll: 'Location:'; 
			  nextPutAll: ((self checkerLocation) printString ).! !

!Observable methodsFor: 'as yet unclassified' stamp: 'AhmedSoliman 7/13/2015 15:13'!
addObserver: anObserver
    observers add: anObserver.
	anObserver observable: self! !

!Observable methodsFor: 'as yet unclassified' stamp: 'AhmedSoliman 7/11/2015 06:57'!
initialize
    observers := OrderedCollection new.! !

!Observable methodsFor: 'as yet unclassified' stamp: 'AhmedSoliman 7/11/2015 06:58'!
notifyObservers
    observers do: [ :each | each notify ].! !

!Observable methodsFor: 'as yet unclassified' stamp: 'AhmedSoliman 7/11/2015 06:58'!
removeObserver: anObserver
    observers remove: anObserver.! !

Object subclass: #Observer
	instanceVariableNames: 'observable'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!Observer commentStamp: 'AhmedSoliman 7/11/2015 07:01' prior: 0!
An Observer for changes in the observable class!

Observer subclass: #MockView
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!MockView commentStamp: 'AhmedSoliman 7/13/2015 14:54' prior: 0!
This is a stub class to be used as a model when adding view notifications!

!Observer methodsFor: 'as yet unclassified' stamp: 'AhmedSoliman 7/11/2015 07:03'!
notify
    "Action to notify on e.g.: Change in the checker location"
    Transcript show: 'Some things changed in ', observable asString.! !

!Observer methodsFor: 'as yet unclassified' stamp: 'AhmedSoliman 7/11/2015 07:01'!
observable
    ^ observable.! !

!Observer methodsFor: 'as yet unclassified' stamp: 'AhmedSoliman 7/11/2015 07:01'!
observable: anObject
    observable := anObject.! !

Object subclass: #Player
	instanceVariableNames: 'playerName checkerColor'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!Player commentStamp: 'AhmedSoliman 7/13/2015 14:52' prior: 0!
I represent the backgammon players of the game!

!Player class methodsFor: 'initialize' stamp: 'jChizmar 7/15/2015 20:32'!
createCheckers


	| i myCheckers |
	i:=0.
	myCheckers := Array new.
	(i<14) whileTrue:
	[ 
		myCheckers at: i put: Checker new.
		i := i+1.
	 ]! !

!Player class methodsFor: 'initialize' stamp: 'jChizmar 7/15/2015 20:36'!
name: nameIn	 checkerColor: colorIn.
	^ self new
		name:nameIn;
		checkerColor:colorIn.! !

!Player class methodsFor: 'initialize' stamp: 'jChizmar 7/15/2015 20:39'!
nameOfPlayer: nameIn	 checkerColor: colorIn.
	^ self new
		nameOfPlayer:nameIn;
		checkerColor:colorIn.! !

!Player methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:12'!
checkerColor
	^ checkerColor! !

!Player methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:12'!
checkerColor: anObject
	checkerColor := anObject! !

!Player methodsFor: 'initialize' stamp: 'jChizmar 7/15/2015 20:39'!
name: nameIn checkerColor:colorIn
	"comment stating purpose of message"

	self nameOfPlayer: nameIn.
	self checkerColor:colorIn.
	^self.! !

!Player methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:43'!
nameOfPlayer
	^ playerName.! !

!Player methodsFor: 'initialize' stamp: 'jChizmar 7/15/2015 20:45'!
nameOfPlayer: nameIn
	"comment stating purpose of message"

	playerName := nameIn.
.! !

!Player methodsFor: 'initialize' stamp: 'jChizmar 7/15/2015 20:40'!
nameofPlayer: nameIn checkerColor:colorIn
	"comment stating purpose of message"

	self nameOfPlayer: nameIn.
	self checkerColor:colorIn.
	^self.! !

!Player methodsFor: 'as yet unclassified' stamp: 'jChizmar 7/11/2015 21:08'!
printOn: aStream
	aStream nextPutAll:'PlayerClass'.! !
MainBoard initialize!
